
# Emperor  ---------------------------------------------------

#load packages
library(sp)
library(raster)
library(biomod2)

#set directory
setwd("D:/TESE/Climate Change/Biomod2")

#read position files (a two columns file with long and lat)

xy<-read.table("BBA.txt", head=TRUE)
head(xy)
#convert it to a spatial object
SP<-SpatialPoints(xy)
head(xy)
tail(xy)

plot(SP)

#load environmental predictors and stack it
setwd("D:/TESE/Climate Change/Biomod2/Ascs")

bath<-raster("bath.asc")
chl<-raster("chlor.asc")
ice<-raster("ice.asc")
sst<-raster("sst.asc")
wind<-raster("wind.asc")

envi<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#format the data to be modelled
models<-BIOMOD_FormatingData(SP,
                          envi,
                          resp.xy = NULL,
                          resp.name = "models",
                          eval.resp.var = NULL,
                          eval.expl.var = envi,
                          eval.resp.xy = SP,
                          PA.nb.rep = 10,
                          PA.nb.absences =10000 , 
                          PA.strategy = 'sre', 
                          PA.dist.min = 0,
                          PA.dist.max = NULL,
                          PA.sre.quant = 0.025,
                          PA.table = NULL,
                          na.rm = TRUE)

myBiomodOptions<-BIOMOD_ModelingOptions()

myBiomodOptions<-BIOMOD_ModelingOptions(
  MAXENT = list(path_to_maxent.jar = 'D:/Maxent/',
                memory_allocated = 1024,
                maximumiterations = 100,
                visible = FALSE,
                linear = TRUE,
                quadratic = TRUE,
                product = TRUE,
                threshold = TRUE,
                hinge = TRUE,
                lq2lqptthreshold = 80,
                l2lqthreshold = 20,
                hingethreshold = 15,
                beta_threshold = -1,
                beta_categorical = -1,
                beta_lqp = -1,
                beta_hinge = -1,
                defaultprevalence = 0.5))

#run models
Models<-BIOMOD_Modeling(models,
                     models = c('ANN','CTA','FDA','GAM','GBM','GLM','MARS',
                                'MAXENT','RF','SRE'),
                     models.options = myBiomodOptions,
                     NbRunEval=1,
                     DataSplit=80,
                     Yweights=NULL,
                     Prevalence=NULL,
                     VarImport=20,
                     models.eval.meth = c('ROC', 'TSS'),
                     SaveObj = TRUE,
                     rescal.all.models = FALSE,
                     do.full.models = FALSE,
                     modeling.id = as.character(format(Sys.time(), '%s')))


eval<-get_evaluations(Models, as.data.frame=TRUE)
write.table(eval, "D:/TESE/Climate Change/Biomod2/BBA/values.txt", sep="\t")

import<-get_variables_importance(Models)
write.table(import, "D:/TESE/Climate Change/Biomod2/BBA/importance.txt", sep="\t")

#run ensembling
ensemble<-BIOMOD_EnsembleModeling(Models,
                                      chosen.models = 'all',
                                      em.by = 'PA_dataset+repet',
                                      eval.metric = 'all',
                                      eval.metric.quality.threshold = NULL,
                                      models.eval.meth = c('ROC', 'TSS'),
                                      prob.mean = TRUE,
                                      prob.cv = FALSE,
                                      prob.ci = FALSE,
                                      prob.ci.alpha = 0.05,
                                      prob.median = FALSE,
                                      committee.averaging = FALSE,
                                      prob.mean.weight = FALSE,
                                      prob.mean.weight.decay = 'proportional',
                                      VarImport = 0)


#forecast the ensembled model to generate the predictions 
forecast<-BIOMOD_EnsembleForecasting(ensemble,
                                         projection.output = NULL,
                                         new.env = envi,
                                         xy.new.env = NULL,
                                         selected.models = 'all',
                                         proj.name = "pred",
                                         binary.meth = NULL,
                                         filtered.meth = NULL,
                                         compress = FALSE)



#re-upload the bathymetry file
setwd("D:/TESE/Climate Change/Biomod2")

bath<-raster("bath.asc")


#upload environment to project distribution 

setwd("D:/TESE/Climate Change/Biomod2/RCP26/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP26/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP45/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP45/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP85/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP85/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/BBA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

# Grey-headed Albatross ---------------------------------------------------

#load packages
library(sp)
library(raster)
library(biomod2)

#set directory
setwd("D:/TESE/Climate Change/Biomod2")

#read position files (a two columns file with long and lat)

xy<-read.table("GHA.txt", head=TRUE)

#converti it to a spatial object
SP<-SpatialPoints(xy)
head(xy)
tail(xy)

plot(SP)

#load environmental predictors and stack it
setwd("D:/TESE/Climate Change/Biomod2/Ascs")

bath<-raster("bath.asc")
chl<-raster("chlor.asc")
ice<-raster("ice.asc")
sst<-raster("sst.asc")
wind<-raster("wind.asc")

envi<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#format the data to be modelled
models<-BIOMOD_FormatingData(SP,
                             envi,
                             resp.xy = NULL,
                             resp.name = "models",
                             eval.resp.var = NULL,
                             eval.expl.var = envi,
                             eval.resp.xy = SP,
                             PA.nb.rep = 10,
                             PA.nb.absences =10000 , 
                             PA.strategy = 'sre', 
                             PA.dist.min = 0,
                             PA.dist.max = NULL,
                             PA.sre.quant = 0.025,
                             PA.table = NULL,
                             na.rm = TRUE)

myBiomodOptions<-BIOMOD_ModelingOptions()

myBiomodOptions<-BIOMOD_ModelingOptions(
  MAXENT = list(path_to_maxent.jar = 'D:/Maxent/',
                memory_allocated = 1024,
                maximumiterations = 100,
                visible = FALSE,
                linear = TRUE,
                quadratic = TRUE,
                product = TRUE,
                threshold = TRUE,
                hinge = TRUE,
                lq2lqptthreshold = 80,
                l2lqthreshold = 20,
                hingethreshold = 15,
                beta_threshold = -1,
                beta_categorical = -1,
                beta_lqp = -1,
                beta_hinge = -1,
                defaultprevalence = 0.5))

#run models
Models<-BIOMOD_Modeling(models,
                        models = c('ANN','CTA','FDA','GAM','GBM','GLM','MARS',
                                   'MAXENT','RF','SRE'),
                        models.options = myBiomodOptions,
                        NbRunEval=1,
                        DataSplit=80,
                        Yweights=NULL,
                        Prevalence=NULL,
                        VarImport=20,
                        models.eval.meth = c('ROC', 'TSS'),
                        SaveObj = TRUE,
                        rescal.all.models = FALSE,
                        do.full.models = FALSE,
                        modeling.id = as.character(format(Sys.time(), '%s')))


eval<-get_evaluations(Models, as.data.frame=TRUE)
write.table(eval, "D:/TESE/Climate Change/Biomod2/GHA/values.txt", sep="\t")

import<-get_variables_importance(Models)
write.table(import, "D:/TESE/Climate Change/Biomod2/GHA/importance.txt", sep="\t")

#run ensembling
ensemble<-BIOMOD_EnsembleModeling(Models,
                                  chosen.models = 'all',
                                  em.by = 'PA_dataset+repet',
                                  eval.metric = 'all',
                                  eval.metric.quality.threshold = NULL,
                                  models.eval.meth = c('ROC', 'TSS'),
                                  prob.mean = TRUE,
                                  prob.cv = FALSE,
                                  prob.ci = FALSE,
                                  prob.ci.alpha = 0.05,
                                  prob.median = FALSE,
                                  committee.averaging = FALSE,
                                  prob.mean.weight = FALSE,
                                  prob.mean.weight.decay = 'proportional',
                                  VarImport = 0)


#forecast the ensembled model to generate the predictions 
forecast<-BIOMOD_EnsembleForecasting(ensemble,
                                     projection.output = NULL,
                                     new.env = envi,
                                     xy.new.env = NULL,
                                     selected.models = 'all',
                                     proj.name = "pred",
                                     binary.meth = NULL,
                                     filtered.meth = NULL,
                                     compress = FALSE)



#re-upload the bathymetry file
setwd("D:/TESE/Climate Change/Biomod2")

bath<-raster("bath.asc")


#upload environment to project distribution 

setwd("D:/TESE/Climate Change/Biomod2/RCP26/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP26/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP45/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP45/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP85/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP85/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/GHA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

# Northern Giant Petrel ----------------------------------------------------


#load packages
library(sp)
library(raster)
library(biomod2)

#set directory
setwd("D:/TESE/Climate Change/Biomod2")

#read position files (a two columns file with long and lat)

xy<-read.table("NGP.txt", head=TRUE)

#converti it to a spatial object
SP<-SpatialPoints(xy)
head(xy)
tail(xy)

plot(SP)

#load environmental predictors and stack it
setwd("D:/TESE/Climate Change/Biomod2/Ascs")

bath<-raster("bath.asc")
chl<-raster("chlor.asc")
ice<-raster("ice.asc")
sst<-raster("sst.asc")
wind<-raster("wind.asc")

envi<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#format the data to be modelled
models<-BIOMOD_FormatingData(SP,
                             envi,
                             resp.xy = NULL,
                             resp.name = "models",
                             eval.resp.var = NULL,
                             eval.expl.var = envi,
                             eval.resp.xy = SP,
                             PA.nb.rep = 10,
                             PA.nb.absences =10000 , 
                             PA.strategy = 'sre', 
                             PA.dist.min = 0,
                             PA.dist.max = NULL,
                             PA.sre.quant = 0.025,
                             PA.table = NULL,
                             na.rm = TRUE)

myBiomodOptions<-BIOMOD_ModelingOptions()

myBiomodOptions<-BIOMOD_ModelingOptions(
  MAXENT = list(path_to_maxent.jar = 'D:/Maxent/',
                memory_allocated = 1024,
                maximumiterations = 100,
                visible = FALSE,
                linear = TRUE,
                quadratic = TRUE,
                product = TRUE,
                threshold = TRUE,
                hinge = TRUE,
                lq2lqptthreshold = 80,
                l2lqthreshold = 20,
                hingethreshold = 15,
                beta_threshold = -1,
                beta_categorical = -1,
                beta_lqp = -1,
                beta_hinge = -1,
                defaultprevalence = 0.5))

#run models
Models<-BIOMOD_Modeling(models,
                        models = c('ANN','CTA','FDA','GAM','GBM','GLM','MARS',
                                   'MAXENT','RF','SRE'),
                        models.options = myBiomodOptions,
                        NbRunEval=1,
                        DataSplit=80,
                        Yweights=NULL,
                        Prevalence=NULL,
                        VarImport=20,
                        models.eval.meth = c('ROC', 'TSS'),
                        SaveObj = TRUE,
                        rescal.all.models = FALSE,
                        do.full.models = FALSE,
                        modeling.id = as.character(format(Sys.time(), '%s')))


eval<-get_evaluations(Models, as.data.frame=TRUE)
write.table(eval, "D:/TESE/Climate Change/Biomod2/NGP/values.txt", sep="\t")

import<-get_variables_importance(Models)
write.table(import, "D:/TESE/Climate Change/Biomod2/NGP/importance.txt", sep="\t")

#run ensembling
ensemble<-BIOMOD_EnsembleModeling(Models,
                                  chosen.models = 'all',
                                  em.by = 'PA_dataset+repet',
                                  eval.metric = 'all',
                                  eval.metric.quality.threshold = NULL,
                                  models.eval.meth = c('ROC', 'TSS'),
                                  prob.mean = TRUE,
                                  prob.cv = FALSE,
                                  prob.ci = FALSE,
                                  prob.ci.alpha = 0.05,
                                  prob.median = FALSE,
                                  committee.averaging = FALSE,
                                  prob.mean.weight = FALSE,
                                  prob.mean.weight.decay = 'proportional',
                                  VarImport = 0)


#forecast the ensembled model to generate the predictions 
forecast<-BIOMOD_EnsembleForecasting(ensemble,
                                     projection.output = NULL,
                                     new.env = envi,
                                     xy.new.env = NULL,
                                     selected.models = 'all',
                                     proj.name = "pred",
                                     binary.meth = NULL,
                                     filtered.meth = NULL,
                                     compress = FALSE)



#re-upload the bathymetry file
setwd("D:/TESE/Climate Change/Biomod2")

bath<-raster("bath.asc")


#upload environment to project distribution 

setwd("D:/TESE/Climate Change/Biomod2/RCP26/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP26/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP45/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP45/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP85/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP85/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/NGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


# Southern Giant Petrel ------------------------------------------------------


#load packages
library(sp)
library(raster)
library(biomod2)

#set directory
setwd("D:/TESE/Climate Change/Biomod2")

#read position files (a two columns file with long and lat)

xy<-read.table("SGP.txt", head=TRUE)

#converti it to a spatial object
SP<-SpatialPoints(xy)
head(xy)
tail(xy)

plot(SP)

#load environmental predictors and stack it
setwd("D:/TESE/Climate Change/Biomod2/Ascs")

bath<-raster("bath.asc")
chl<-raster("chlor.asc")
ice<-raster("ice.asc")
sst<-raster("sst.asc")
wind<-raster("wind.asc")

envi<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#format the data to be modelled
models<-BIOMOD_FormatingData(SP,
                             envi,
                             resp.xy = NULL,
                             resp.name = "models",
                             eval.resp.var = NULL,
                             eval.expl.var = envi,
                             eval.resp.xy = SP,
                             PA.nb.rep = 10,
                             PA.nb.absences =10000 , 
                             PA.strategy = 'sre', 
                             PA.dist.min = 0,
                             PA.dist.max = NULL,
                             PA.sre.quant = 0.025,
                             PA.table = NULL,
                             na.rm = TRUE)

myBiomodOptions<-BIOMOD_ModelingOptions()

myBiomodOptions<-BIOMOD_ModelingOptions(
  MAXENT = list(path_to_maxent.jar = 'D:/Maxent/',
                memory_allocated = 1024,
                maximumiterations = 100,
                visible = FALSE,
                linear = TRUE,
                quadratic = TRUE,
                product = TRUE,
                threshold = TRUE,
                hinge = TRUE,
                lq2lqptthreshold = 80,
                l2lqthreshold = 20,
                hingethreshold = 15,
                beta_threshold = -1,
                beta_categorical = -1,
                beta_lqp = -1,
                beta_hinge = -1,
                defaultprevalence = 0.5))

#run models
Models<-BIOMOD_Modeling(models,
                        models = c('ANN','CTA','FDA','GAM','GBM','GLM','MARS',
                                   'MAXENT','RF','SRE'),
                        models.options = myBiomodOptions,
                        NbRunEval=1,
                        DataSplit=80,
                        Yweights=NULL,
                        Prevalence=NULL,
                        VarImport=20,
                        models.eval.meth = c('ROC', 'TSS'),
                        SaveObj = TRUE,
                        rescal.all.models = FALSE,
                        do.full.models = FALSE,
                        modeling.id = as.character(format(Sys.time(), '%s')))


eval<-get_evaluations(Models, as.data.frame=TRUE)
write.table(eval, "D:/TESE/Climate Change/Biomod2/SGP/values.txt", sep="\t")

import<-get_variables_importance(Models)
write.table(import, "D:/TESE/Climate Change/Biomod2/SGP/importance.txt", sep="\t")

#run ensembling
ensemble<-BIOMOD_EnsembleModeling(Models,
                                  chosen.models = 'all',
                                  em.by = 'PA_dataset+repet',
                                  eval.metric = 'all',
                                  eval.metric.quality.threshold = NULL,
                                  models.eval.meth = c('ROC', 'TSS'),
                                  prob.mean = TRUE,
                                  prob.cv = FALSE,
                                  prob.ci = FALSE,
                                  prob.ci.alpha = 0.05,
                                  prob.median = FALSE,
                                  committee.averaging = FALSE,
                                  prob.mean.weight = FALSE,
                                  prob.mean.weight.decay = 'proportional',
                                  VarImport = 0)


#forecast the ensembled model to generate the predictions 
forecast<-BIOMOD_EnsembleForecasting(ensemble,
                                     projection.output = NULL,
                                     new.env = envi,
                                     xy.new.env = NULL,
                                     selected.models = 'all',
                                     proj.name = "pred",
                                     binary.meth = NULL,
                                     filtered.meth = NULL,
                                     compress = FALSE)



#re-upload the bathymetry file
setwd("D:/TESE/Climate Change/Biomod2")

bath<-raster("bath.asc")


#upload environment to project distribution 

setwd("D:/TESE/Climate Change/Biomod2/RCP26/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP26/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP45/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP45/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP85/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP85/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/SGP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


# Tristan Albatross -------------------------------------------------------


#load packages
library(sp)
library(raster)
library(biomod2)

#set directory
setwd("D:/TESE/Climate Change/Biomod2")

#read position files (a two columns file with long and lat)

xy<-read.table("TA.txt", head=TRUE)

#converti it to a spatial object
SP<-SpatialPoints(xy)
head(xy)
tail(xy)

plot(SP)

#load environmental predictors and stack it
setwd("D:/TESE/Climate Change/Biomod2/Ascs")

bath<-raster("bath.asc")
chl<-raster("chlor.asc")
ice<-raster("ice.asc")
sst<-raster("sst.asc")
wind<-raster("wind.asc")

envi<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/TA")

#format the data to be modelled
models<-BIOMOD_FormatingData(SP,
                             envi,
                             resp.xy = NULL,
                             resp.name = "models",
                             eval.resp.var = NULL,
                             eval.expl.var = envi,
                             eval.resp.xy = SP,
                             PA.nb.rep = 10,
                             PA.nb.absences =10000 , 
                             PA.strategy = 'sre', 
                             PA.dist.min = 0,
                             PA.dist.max = NULL,
                             PA.sre.quant = 0.025,
                             PA.table = NULL,
                             na.rm = TRUE)

myBiomodOptions<-BIOMOD_ModelingOptions()

myBiomodOptions<-BIOMOD_ModelingOptions(
  MAXENT = list(path_to_maxent.jar = 'D:/Maxent/',
                memory_allocated = 1024,
                maximumiterations = 100,
                visible = FALSE,
                linear = TRUE,
                quadratic = TRUE,
                product = TRUE,
                threshold = TRUE,
                hinge = TRUE,
                lq2lqptthreshold = 80,
                l2lqthreshold = 20,
                hingethreshold = 15,
                beta_threshold = -1,
                beta_categorical = -1,
                beta_lqp = -1,
                beta_hinge = -1,
                defaultprevalence = 0.5))

#run models
Models<-BIOMOD_Modeling(models,
                        models = c('ANN','CTA','FDA','GAM','GBM','GLM','MARS',
                                   'MAXENT','RF','SRE'),
                        models.options = myBiomodOptions,
                        NbRunEval=1,
                        DataSplit=80,
                        Yweights=NULL,
                        Prevalence=NULL,
                        VarImport=20,
                        models.eval.meth = c('ROC', 'TSS'),
                        SaveObj = TRUE,
                        rescal.all.models = FALSE,
                        do.full.models = FALSE,
                        modeling.id = as.character(format(Sys.time(), '%s')))


eval<-get_evaluations(Models, as.data.frame=TRUE)
write.table(eval, "D:/TESE/Climate Change/Biomod2/TA/values.txt", sep="\t")

import<-get_variables_importance(Models)
write.table(import, "D:/TESE/Climate Change/Biomod2/TA/importance.txt", sep="\t")

#run ensembling
ensemble<-BIOMOD_EnsembleModeling(Models,
                                  chosen.models = 'all',
                                  em.by = 'PA_dataset+repet',
                                  eval.metric = 'all',
                                  eval.metric.quality.threshold = NULL,
                                  models.eval.meth = c('ROC', 'TSS'),
                                  prob.mean = TRUE,
                                  prob.cv = FALSE,
                                  prob.ci = FALSE,
                                  prob.ci.alpha = 0.05,
                                  prob.median = FALSE,
                                  committee.averaging = FALSE,
                                  prob.mean.weight = FALSE,
                                  prob.mean.weight.decay = 'proportional',
                                  VarImport = 0)


#forecast the ensembled model to generate the predictions 
forecast<-BIOMOD_EnsembleForecasting(ensemble,
                                     projection.output = NULL,
                                     new.env = envi,
                                     xy.new.env = NULL,
                                     selected.models = 'all',
                                     proj.name = "pred",
                                     binary.meth = NULL,
                                     filtered.meth = NULL,
                                     compress = FALSE)



#re-upload the bathymetry file
setwd("D:/TESE/Climate Change/Biomod2")

bath<-raster("bath.asc")


#upload environment to project distribution 

setwd("D:/TESE/Climate Change/Biomod2/RCP26/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP26/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP45/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP45/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP85/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP85/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/TA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


# Wandering Albatross ------------------------------------------------------------


#load packages
library(sp)
library(raster)
library(biomod2)

#set directory
setwd("D:/TESE/Climate Change/Biomod2")

#read position files (a two columns file with long and lat)

xy<-read.table("WA.txt", head=TRUE)

#converti it to a spatial object
SP<-SpatialPoints(xy)
head(xy)
tail(xy)


plot(SP)

#load environmental predictors and stack it
setwd("D:/TESE/Climate Change/Biomod2/Ascs")

bath<-raster("bath.asc")
chl<-raster("chlor.asc")
ice<-raster("ice.asc")
sst<-raster("sst.asc")
wind<-raster("wind.asc")

envi<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/WA")

#format the data to be modelled
models<-BIOMOD_FormatingData(SP,
                             envi,
                             resp.xy = NULL,
                             resp.name = "models",
                             eval.resp.var = NULL,
                             eval.expl.var = envi,
                             eval.resp.xy = SP,
                             PA.nb.rep = 10,
                             PA.nb.absences =10000 , 
                             PA.strategy = 'sre', 
                             PA.dist.min = 0,
                             PA.dist.max = NULL,
                             PA.sre.quant = 0.025,
                             PA.table = NULL,
                             na.rm = TRUE)

myBiomodOptions<-BIOMOD_ModelingOptions()

myBiomodOptions<-BIOMOD_ModelingOptions(
  MAXENT = list(path_to_maxent.jar = 'D:/Maxent/',
                memory_allocated = 1024,
                maximumiterations = 100,
                visible = FALSE,
                linear = TRUE,
                quadratic = TRUE,
                product = TRUE,
                threshold = TRUE,
                hinge = TRUE,
                lq2lqptthreshold = 80,
                l2lqthreshold = 20,
                hingethreshold = 15,
                beta_threshold = -1,
                beta_categorical = -1,
                beta_lqp = -1,
                beta_hinge = -1,
                defaultprevalence = 0.5))

#run models
Models<-BIOMOD_Modeling(models,
                        models = c('ANN','CTA','FDA','GAM','GBM','GLM','MARS',
                                   'MAXENT','RF','SRE'),
                        models.options = myBiomodOptions,
                        NbRunEval=1,
                        DataSplit=80,
                        Yweights=NULL,
                        Prevalence=NULL,
                        VarImport=20,
                        models.eval.meth = c('ROC', 'TSS'),
                        SaveObj = TRUE,
                        rescal.all.models = FALSE,
                        do.full.models = FALSE,
                        modeling.id = as.character(format(Sys.time(), '%s')))


eval<-get_evaluations(Models, as.data.frame=TRUE)
write.table(eval, "D:/TESE/Climate Change/Biomod2/WA/values.txt", sep="\t")

import<-get_variables_importance(Models)
write.table(import, "D:/TESE/Climate Change/Biomod2/WA/importance.txt", sep="\t")

#run ensembling
ensemble<-BIOMOD_EnsembleModeling(Models,
                                  chosen.models = 'all',
                                  em.by = 'PA_dataset+repet',
                                  eval.metric = 'all',
                                  eval.metric.quality.threshold = NULL,
                                  models.eval.meth = c('ROC', 'TSS'),
                                  prob.mean = TRUE,
                                  prob.cv = FALSE,
                                  prob.ci = FALSE,
                                  prob.ci.alpha = 0.05,
                                  prob.median = FALSE,
                                  committee.averaging = FALSE,
                                  prob.mean.weight = FALSE,
                                  prob.mean.weight.decay = 'proportional',
                                  VarImport = 0)


#forecast the ensembled model to generate the predictions 
forecast<-BIOMOD_EnsembleForecasting(ensemble,
                                     projection.output = NULL,
                                     new.env = envi,
                                     xy.new.env = NULL,
                                     selected.models = 'all',
                                     proj.name = "pred",
                                     binary.meth = NULL,
                                     filtered.meth = NULL,
                                     compress = FALSE)



#re-upload the bathymetry file
setwd("D:/TESE/Climate Change/Biomod2")

bath<-raster("bath.asc")


#upload environment to project distribution 

setwd("D:/TESE/Climate Change/Biomod2/RCP26/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP26/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP45/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP45/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP85/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP85/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WA")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)



# White-chinned Petrel ------------------------------------------------------------


#load packages
library(sp)
library(raster)
library(biomod2)

#set directory
setwd("D:/TESE/Climate Change/Biomod2")

#read position files (a two columns file with long and lat)

xy<-read.table("WCP.txt", head=TRUE)

#converti it to a spatial object
SP<-SpatialPoints(xy)
head(xy)
tail(xy)

plot(SP)

#load environmental predictors and stack it
setwd("D:/TESE/Climate Change/Biomod2/Ascs")

bath<-raster("bath.asc")
chl<-raster("chlor.asc")
ice<-raster("ice.asc")
sst<-raster("sst.asc")
wind<-raster("wind.asc")

envi<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#format the data to be modelled
models<-BIOMOD_FormatingData(SP,
                             envi,
                             resp.xy = NULL,
                             resp.name = "models",
                             eval.resp.var = NULL,
                             eval.expl.var = envi,
                             eval.resp.xy = SP,
                             PA.nb.rep = 10,
                             PA.nb.absences =10000 , 
                             PA.strategy = 'sre', 
                             PA.dist.min = 0,
                             PA.dist.max = NULL,
                             PA.sre.quant = 0.025,
                             PA.table = NULL,
                             na.rm = TRUE)

myBiomodOptions<-BIOMOD_ModelingOptions()

myBiomodOptions<-BIOMOD_ModelingOptions(
  MAXENT = list(path_to_maxent.jar = 'D:/Maxent/',
                memory_allocated = 1024,
                maximumiterations = 100,
                visible = FALSE,
                linear = TRUE,
                quadratic = TRUE,
                product = TRUE,
                threshold = TRUE,
                hinge = TRUE,
                lq2lqptthreshold = 80,
                l2lqthreshold = 20,
                hingethreshold = 15,
                beta_threshold = -1,
                beta_categorical = -1,
                beta_lqp = -1,
                beta_hinge = -1,
                defaultprevalence = 0.5))

#run models
Models<-BIOMOD_Modeling(models,
                        models = c('ANN','CTA','FDA','GAM','GBM','GLM','MARS',
                                   'MAXENT','RF','SRE'),
                        models.options = myBiomodOptions,
                        NbRunEval=1,
                        DataSplit=80,
                        Yweights=NULL,
                        Prevalence=NULL,
                        VarImport=20,
                        models.eval.meth = c('ROC', 'TSS'),
                        SaveObj = TRUE,
                        rescal.all.models = FALSE,
                        do.full.models = FALSE,
                        modeling.id = as.character(format(Sys.time(), '%s')))


eval<-get_evaluations(Models, as.data.frame=TRUE)
write.table(eval, "D:/TESE/Climate Change/Biomod2/WCP/values.txt", sep="\t")

import<-get_variables_importance(Models)
write.table(import, "D:/TESE/Climate Change/Biomod2/WCP/importance.txt", sep="\t")

#run ensembling
ensemble<-BIOMOD_EnsembleModeling(Models,
                                  chosen.models = 'all',
                                  em.by = 'PA_dataset+repet',
                                  eval.metric = 'all',
                                  eval.metric.quality.threshold = NULL,
                                  models.eval.meth = c('ROC', 'TSS'),
                                  prob.mean = TRUE,
                                  prob.cv = FALSE,
                                  prob.ci = FALSE,
                                  prob.ci.alpha = 0.05,
                                  prob.median = FALSE,
                                  committee.averaging = FALSE,
                                  prob.mean.weight = FALSE,
                                  prob.mean.weight.decay = 'proportional',
                                  VarImport = 0)


#forecast the ensembled model to generate the predictions 
forecast<-BIOMOD_EnsembleForecasting(ensemble,
                                     projection.output = NULL,
                                     new.env = envi,
                                     xy.new.env = NULL,
                                     selected.models = 'all',
                                     proj.name = "pred",
                                     binary.meth = NULL,
                                     filtered.meth = NULL,
                                     compress = FALSE)



#re-upload the bathymetry file
setwd("D:/TESE/Climate Change/Biomod2")

bath<-raster("bath.asc")


#upload environment to project distribution 

setwd("D:/TESE/Climate Change/Biomod2/RCP26/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP26/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp26_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP45/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP45/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp45_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP60/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp60_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)


setwd("D:/TESE/Climate Change/Biomod2/RCP85/50y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_50",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/TESE/Climate Change/Biomod2/RCP85/100y") #CHANGE FOLDER
chl<-raster("chlor.asc")
sst<-raster("sst.asc")
ice<-raster("ice.asc")
wind<-raster("wind.asc")

projec<-stack(bath,chl,ice,sst,wind)
#bath is the same file from previous step, bathymetry does not 
#change significantly overtime

setwd("D:/TESE/Climate Change/Biomod2/WCP")

#project distribution - CHANGE NAME OF THE PROJECTS IN THE THIRD LINE
#this will save projections as a .gri file in the respective folder
proj<-BIOMOD_Projection(Models,
                        projec,
                        "rcp85_100",
                        xy.new.env = NULL,
                        selected.models = 'all',
                        binary.meth = NULL,
                        filtered.meth = NULL,
                        compress = TRUE,
                        build.clamping.mask = TRUE)

setwd("D:/R-Scripts")
