#run Geographically Weighted PCA

library(mvnormtest)
library(sp)
library(GWmodel)
library(ggplot2)

setwd("D:/TESE/Climate Change/GWPCA/ALL")

coords<- read.delim("D:/TESE/Climate Change/GWPCA/ALL/coords.txt")


data<- read.delim("D:/TESE/Climate Change/GWPCA/ALL/data.txt")

head(data)

vars.df<-c("WCP","WA","TA","SGP","NGP","GHA","BBA","HIGH","LOW",
           
           "WCP26","WA26","TA26","SGP26","NGP26","GHA26","BBA26","H26","L26",
           "WCP45","WA45","TA45","SGP45","NGP45","GHA45","BBA45","L45","H45",
           "WCP60","WA60","TA60","SGP60","NGP60","GHA60","BBA60","H60","L60",
           "WCP85","WA85","TA85","SGP85","NGP85","GHA85","BBA85","H85","L85")
vars.df

xy<-SpatialPoints(coords)


head(data)
#test for multinormality
C <- t(data[1:897,1:45])
mshapiro.test(C)


#create distance matrix

gDM<-gw.dist(dp.locat=coordinates(xy))

#calculate bandwidth
spdf<-SpatialPointsDataFrame(coords,data)
pred.spdf<-SpatialPointsDataFrame(coords,data)
bw.pc<-bw.gwpca(data=spdf,vars=vars.df,k=2, robust=FALSE,kernel="bisquare",adaptive=FALSE,p=2,
                theta=0, longlat=F,dMat=gDM)
#GWPCA

pca.res<-gwpca(data=spdf, elocat=pred.spdf, vars=vars.df, k = 2, robust = FALSE, kernel = "bisquare",
               adaptive = FALSE, bw=bw.pc, p = 2, theta = 0, longlat = F, cv = T,
               dMat=gDM)

#write and export results
local.loadings1 <- pca.res$loadings[, , 1]
local.loadings2 <- pca.res$loadings[, , 2]

variance<-pca.res$var
head(variance)
crossval<-pca.res$CV
head(crossval)

pcs<-data.frame(local.loadings1,local.loadings2)


write.table(pcs, "D:/TESE/Climate Change/GWPCA/ALL/loadings.txt", 
            sep="\t")
write.table(variance, "D:/TESE/Climate Change/GWPCA/ALL/variance.txt", 
            sep="\t")
write.table(crossval, "D:/TESE/Climate Change/GWPCA/ALL/crossvalidation.txt", 
            sep="\t")

mc1<-montecarlo.gwpca.1(spdf, bw.pc, vars=vars.df, k = 2, nsims=99,robust = FALSE, kernel = "bisquare",
                   adaptive = FALSE, p = 2, theta = 0, longlat = F, dMat=gDM)

mc2<-montecarlo.gwpca.2(spdf, bw.pc,vars=vars.df, k = 2, nsims=99,robust = FALSE, kernel = "bisquare",
                        adaptive = FALSE, p = 2, theta = 0, longlat = F, dMat=gDM)
mc1

X11(width=8,height=5)
mcplot1<-plot.mcsims(mc1)
mcplot2<-plot.mcsims(mc2)

setwd("D:/R-Scripts")
